@@ -1,9 +1,23 @@
+import sys
+
 from . import Archive
 from . import Find
 from . import ParseArgs
 from . import Interact
 
 
+def iter_urls(opt):
+    """Iterate given urls for saving."""
+    try:
+        for x in opt["urls"]:
+            Archive.archive(Find.extract_uri_recursive(x, opt["level"]),
+                            x, opt["retry"])
+    except KeyboardInterrupt:
+        print("[!]Interrupted!", file=sys.stderr)
+        print("[!]Halt.", file=sys.stderr)
+        exit(1)
+
+
 def main():
     """Main function."""
     opt = ParseArgs.parse_args()
@@ -16,10 +30,7 @@ def main():
         exit(0)
 
     else:
-        for x in opt["urls"]:
-            dic = Find.extract_uri_recursive(x, opt["level"])
-            Archive.archive(dic, x, opt["retry"])
-
+        iter_urls(opt)
         exit(0)
 
 
